import {Component, Input, OnDestroy, OnInit} from '@angular/core';
import {WizardTabComponent} from "../wizard-tab/wizard-tab.component";
import {Subscription} from "rxjs/Subscription";
import {WizardEventService} from "../wizard-event-service";

@Component({
  selector: 'tabbed-wizard',
  templateUrl: './tabbed-wizard.component.html',
  styleUrls: ['./tabbed-wizard.component.scss']
})
export class TabbedWizardComponent implements OnInit, OnDestroy {
  @Input()
  public logoUrl: string;
  @Input()
  public logoHeight: string;

  public tabs: Array<WizardTabComponent> = [];
  private subscription: Subscription;
  private numberOfTabs: number = 0;
  constructor (private wizardEventService: WizardEventService){
  }
  
  ngOnInit() {
    this.subscription = this.wizardEventService.notifyObservable$.subscribe((event) => {
      switch (event.type) {
        case 'continue':
          this.goToNextTab();
          break;
        case 'completeActiveTab':
          this.tabs.forEach((tab) => {
            if (tab.active && !tab.completed) {
              tab.completed = true;
              if (tab.index < this.tabs.length - 1) {
                tab.isCurrentStep = false;
                this.tabs[tab.index + 1].isCurrentStep = true;
              }
            }
          });
          
          break;
      }
    });
  }
  
  ngOnDestroy() {
    this.subscription.unsubscribe();
  }
  
  public addTab(tab: WizardTabComponent) {
    if (this.tabs.length == 0) {
      tab.active = true;
      tab.isCurrentStep = true;
    }
    
    tab.index = this.numberOfTabs;
    this.tabs.push(tab);
    this.numberOfTabs++;
  }
  
  public showTab (clickedTab: WizardTabComponent) {
    if(clickedTab == this.tabs[0] || this.tabs[clickedTab.index - 1].completed) {
      this.tabs.forEach((tab) => {
        tab.active = false;
      });
  
      clickedTab.active = true;
    }
  }
  
  public goToNextTab () {
    let activeTab = this.getActiveTab();
    
    if (activeTab.index >= this.tabs.length - 1)
      console.log('You tried to continue past the last step.');
    else
      this.showTab(this.tabs[activeTab.index+1]);
  }
  
  private getActiveTab () : WizardTabComponent {
    return this.tabs.find((tab) => {
        return tab.active == true;
    });
  }
}
